@@ -18,14 +18,14 @@ from docgen import finder, loader, patcher, converter
 from docgen.utils import timed, debug_traceback
 
 
-DEFAULT_EXCLUDE = (
+DEFAULT_EXCLUDE = [
     r"_*",
     r"*.setup",
     r"*.main",
     r"antigravity",
     r"robot.libraries.Remote",
     r"robot.libraries.Reserved",
-)
+]
 
 
 def filter_include(matches, patterns):
@@ -74,6 +74,13 @@ def create_parser():
         choices=converter.CONVERTERS,
         default="json-html",
     )
+    parser.add_argument(
+        "-e",
+        "--exclude",
+        help="pattern to exclude",
+        action="append",
+        default=DEFAULT_EXCLUDE,
+    )
     parser.add_argument(
         "--no-patches",
         action="store_true",
@@ -125,30 +132,28 @@ def run(raw_args=None):
     if platform.system() == "Darwin":
         multiprocessing.set_start_method("spawn")
 
-    pool = multiprocessing.Pool()
+    with multiprocessing.Pool() as pool:
+        with timed("All"):
+            with timed("Find"):
+                result = pool.map(find, [args])
+                matches, include = result[0]
 
-    with timed("All"):
-        with timed("Find"):
-            result = pool.map(find, [args])
-            matches, include = result[0]
+            with timed("Filter"):
+                matches = filter_include(matches, [include])
+                matches = filter_exclude(matches, args.exclude)
 
-        with timed("Filter"):
-            matches = filter_include(matches, [include])
-            matches = filter_exclude(matches, DEFAULT_EXCLUDE)
+            with timed("Load"):
+                libraries = pool.map(try_load, matches)
+                libraries = [lib for lib in libraries if lib is not None]
 
-        with timed("Load"):
-            libraries = pool.map(try_load, matches)
-            libraries = [lib for lib in libraries if lib is not None]
+            if not args.no_patches:
+                with timed("Patch"):
+                    for lib in libraries:
+                        patcher.apply_all(lib)
 
-        if not args.no_patches:
-            with timed("Patch"):
+            args.output.mkdir(parents=True, exist_ok=True)
+            with timed("Convert"):
                 for lib in libraries:
-                    patcher.apply_all(lib)
+                    converter.convert(lib, args.format, args.output)
 
-        args.output.mkdir(parents=True, exist_ok=True)
-        with timed("Convert"):
-            for lib in libraries:
-                converter.convert(lib, args.format, args.output)
-
-    logging.info("Created %d file(s)", len(libraries))
-    pool.close()
+        logging.info("Created %d file(s)", len(libraries))
