@@ -14,12 +14,16 @@ KEYWORDS = re.compile(r"^\*+\s*((?:User )?Keywords?)", re.MULTILINE | re.IGNOREC
 TASKS = re.compile(r"^\*+\s*(Test Cases?|Tasks?)", re.MULTILINE | re.IGNORECASE)
 
 
-def find_all():
+def find_all(curdir=True):
     matches = set()
+
     matches.update(builtins())
     matches.update(rpaframework())
     matches.update(walk_modules())
-    matches.update(walk_directory(os.getcwd()))
+
+    if curdir:
+        matches.update(walk_directory(os.getcwd()))
+
     return [str(match) for match in matches]
 
 
@@ -56,7 +60,7 @@ def walk_directory(root, libraries=True, resources=True):
         path = stack.pop(0)
         path = path.resolve()
 
-        if path.name.startswith("_"):
+        if path.name.startswith(("_", ".")) or path.parts[-1] == "__pycache__":
             continue
         try:
             if path.is_dir():
