@@ -22,7 +22,7 @@ def patch_params(libdoc):
         return
 
     def _replace_all(text):
-        return re.sub(r":param\s+(.*):", r":\1:", text)
+        return re.sub(r":param\s+(.*):\s+", r":\1: ", text)
 
     try:
         libdoc.doc = _replace_all(libdoc.doc)
